@@ -25,6 +25,8 @@ import relex.util.socket.ProcessClient;
  * This class serves as a wrapper to the C linkparser library.
  * Because it is using C, the class is not internally organized
  * in a very good OOP way. -- Someday, this should be fixed.
+ * 
+ * @deprecated
  */
 public class LinkParserSocketClient extends LinkParserClient
 {
@@ -118,10 +120,19 @@ public class LinkParserSocketClient extends LinkParserClient
 		return Boolean.valueOf(exec(LinkParserProtocol.MSG_IS_ENTITY + word)).booleanValue();
 	}
 
-	public void close() {
+	public void killServer() {
 		client.process(LinkParserProtocol.MSG_KILL_SYSTEM, null);
 	}
 
+	public void close()	{
+		try {
+			client.closeConnection();
+		}
+		catch (java.io.IOException ex) {
+			ex.printStackTrace(System.err);
+		}
+	}
+	
 	void execParse(String sentence) {
 		parseCount++;
 		if ((parseCountBetweenKills != 0) && parseCount >= parseCountBetweenKills) {
